==> wiki3_5_1.zip: wiki3_5_1/plugin/rename/RenameHandler.pm <==
###############################################################################
# 
# ڡ̾ΤѹڡΥԡ򤹤ϥɥ顣
# renameեåƤӽФޤ
# 
###############################################################################
package plugin::rename::RenameHandler;
#use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# μ¹
#==============================================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	
	if($wiki->get_CGI()->param("execute_rename") ne ""){
		return $self->do_rename($wiki);
	} else {
		return $self->rename_form($wiki);
	}
}

#==============================================================================
# ͡ѤΥե
#==============================================================================
sub rename_form {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI;
	my $time = $wiki->get_last_modified($cgi->param('page'));

	if($wiki->config('accept_edit')==0 && !defined($wiki->get_login_info())){
		return $wiki->error("ڡΥ͡ࡦԡϵĤƤޤ");
	}

	$wiki->set_title('͡ࡦԡ',1);

	return "ڡ̾ : " . $cgi->param('page') . "<br>" .
	       "<form method=\"post\" action=\"".$wiki->config('script_name')."\">\n".
	       "  <input type=\"text\" name=\"newpage\" size=\"40\">\n".
	       "  <br>\n".
	       "  <input type=\"radio\"  name=\"do\" value=\"move\" checked>͡\n".
	       "  <input type=\"radio\"  name=\"do\" value=\"movewm\">åĤƥ͡\n".
	       "  <input type=\"radio\"  name=\"do\" value=\"copy\">ԡ\n".
	       "  <input type=\"submit\" name=\"execute_rename\" value=\" ¹ \">\n".
	       "  <input type=\"hidden\" name=\"action\" value=\"RENAME\">".
	       "  <input type=\"hidden\" name=\"lastmodified\" value=\"".&Util::escapeHTML($time)."\">\n".
	       "  <input type=\"hidden\" name=\"page\" value=\"".&Util::escapeHTML($cgi->param('page'))."\">".
	       "</form>\n";
}

#==============================================================================
# ͡¹
#==============================================================================
sub do_rename {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI;

	my $pagename    = $cgi->param("page");
	my $newpagename = $cgi->param("newpage");
	my $do          = $cgi->param("do");
	my $time        = $wiki->get_last_modified($pagename);
	my $buf         = "";
	my $login       = $wiki->get_login_info();

	# 顼å
	if($newpagename eq ""){
		return $wiki->error("ڡꤵƤޤ!!");
	}

	if($wiki->page_exists($newpagename)){
		return $wiki->error("˥͡Υڡ¸ߤޤ!!");
	}

	if($newpagename eq $pagename){
		return $wiki->error("ƱΥڡꤵƤޤ!!");
	}
	
	if(!$wiki->can_modify_page($pagename) || !$wiki->can_modify_page($newpagename)){
		return $wiki->error("ڡԽϵĤƤޤ");
	}
	
	if($wiki->page_exists($pagename)){
		if($cgi->param("lastmodified") < $time){
			return $wiki->error("ڡϴ̤Υ桼ˤäƹƤޤ");
		}
	}

	# FrontPageư褦Ȥˤϥ顼
	if($pagename eq "FrontPage" && $do ne "copy"){
		return $wiki->error("FrontPageư뤳ȤϤǤޤ");
	}

	# ԡ
	$wiki->do_hook("rename");
	my $content = $wiki->get_page($pagename);
	$wiki->save_page($newpagename,$content);
	
	# 
	if($do eq "move"){
		$wiki->save_page($pagename,'');
	}elsif($do eq "movewm"){
		$wiki->save_page($pagename,'[['.$newpagename.']]˰ưޤ');
	}

	# եåεưֵѥå
	if($do eq "copy"){
		$wiki->set_title($pagename."򥳥ԡޤ");
		return $cgi->escapeHTML($pagename)."򥳥ԡޤ";
	} else {
		$wiki->set_title($pagename."͡षޤ");
		return $cgi->escapeHTML($pagename)."͡षޤ";
	}
}

1;

==> wiki3_5_3.zip: wiki3_5_3/plugin/rename/RenameHandler.pm <==
###############################################################################
# 
# ڡ̾ΤѹڡΥԡ򤹤ϥɥ顣
# renameեåƤӽФޤ
# 
###############################################################################
package plugin::rename::RenameHandler;
use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# μ¹
#==============================================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	
	return $self->do_rename($wiki);
}

#==============================================================================
# ͡¹
#==============================================================================
sub do_rename {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI;

	my $pagename    = $cgi->param("page");
	my $newpagename = $cgi->param("newpage");
	my $do          = $cgi->param("do");
	my $time        = $wiki->get_last_modified($pagename);
	my $buf         = "";
	my $login       = $wiki->get_login_info();

	# 顼å
	if($newpagename eq ""){
		return $wiki->error("ڡꤵƤޤ!!");
	}
	if($newpagename =~ /\[|\]/){
		return $wiki->error("ڡ̾˥֥饱åȤޤ뤳ȤϤǤޤ");
	}
	if($newpagename =~ /:/){
		return $wiki->error("ڡ̾˥ޤ뤳ȤϤǤޤ");
	}
	if($wiki->page_exists($newpagename)){
		return $wiki->error("˥͡Υڡ¸ߤޤ!!");
	}
	if($newpagename eq $pagename){
		return $wiki->error("ƱΥڡꤵƤޤ!!");
	}
	if(!$wiki->can_modify_page($pagename) || !$wiki->can_modify_page($newpagename)){
		return $wiki->error("ڡԽϵĤƤޤ");
	}
	if($wiki->page_exists($pagename)){
		if($cgi->param("lastmodified") < $time){
			return $wiki->error("ڡϴ̤Υ桼ˤäƹƤޤ");
		}
	}

	# FrontPageư褦Ȥˤϥ顼
	if($pagename eq "FrontPage" && $do ne "copy"){
		return $wiki->error("FrontPageư뤳ȤϤǤޤ");
	}

	# ԡ
	$wiki->do_hook("rename");
	my $content = $wiki->get_page($pagename);
	$wiki->save_page($newpagename,$content);
	
	# 
	if($do eq "move"){
		$wiki->save_page($pagename,'');
	}elsif($do eq "movewm"){
		$wiki->save_page($pagename,'[['.$newpagename.']]˰ưޤ');
	}

	# եåεưֵѥå
	if($do eq "copy"){
		$wiki->set_title($pagename."򥳥ԡޤ");
		return $cgi->escapeHTML($pagename)."򥳥ԡޤ";
	} else {
		$wiki->set_title($pagename."͡षޤ");
		return $cgi->escapeHTML($pagename)."͡षޤ";
	}
}

1;
